@@ -32,9 +32,10 @@ public:
 private:
   void replaceWithRawStringLiteral(
       const ast_matchers::MatchFinder::MatchResult &Result,
-      const StringLiteral *Literal);
+      const StringLiteral *Literal, StringRef Replacement);
 
   std::string DelimiterStem;
+  const bool ReplaceShorterLiterals;
 };
 
 } // namespace modernize
