@@ -18,11 +18,16 @@ namespace clang {
 namespace tidy {
 namespace readability {
 
+RedundantDeclarationCheck::RedundantDeclarationCheck(StringRef Name,
+                                                     ClangTidyContext *Context)
+    : ClangTidyCheck(Name, Context),
+      IgnoreMacros(Options.getLocalOrGlobal("IgnoreMacros", true)) {}
+
 void RedundantDeclarationCheck::registerMatchers(MatchFinder *Finder) {
   Finder->addMatcher(
-      namedDecl(
-          anyOf(varDecl(unless(isDefinition())),
-                functionDecl(unless(anyOf(isDefinition(), isDefaulted())))))
+      namedDecl(anyOf(varDecl(unless(isDefinition())),
+                      functionDecl(unless(anyOf(isDefinition(), isDefaulted(),
+                                                hasParent(friendDecl()))))))
           .bind("Decl"),
       this);
 }
@@ -36,6 +41,13 @@ void RedundantDeclarationCheck::check(const MatchFinder::MatchResult &Result) {
     return;
   if (Prev->getLocation() == D->getLocation())
     return;
+  if (IgnoreMacros &&
+      (D->getLocation().isMacroID() || Prev->getLocation().isMacroID()))
+    return;
+  // Don't complain when the previous declaration is a friend declaration.
+  for (const auto &Parent : Result.Context->getParents(*Prev))
+    if (Parent.get<FriendDecl>())
+      return;
 
   const SourceManager &SM = *Result.SourceManager;
 
