@@ -314,10 +314,10 @@ const HeaderMapCollector::RegexHeaderMap *getSTLPostfixHeaderMap() {
       {"include/xlocale.h$", "<cstring>"},
       {"bits/atomic_word.h$", "<memory>"},
       {"bits/basic_file.h$", "<fstream>"},
-      {"bits/c++allocator.h$", "<string>"},
-      {"bits/c++config.h$", "<iosfwd>"},
-      {"bits/c++io.h$", "<ios>"},
-      {"bits/c++locale.h$", "<locale>"},
+      {"bits/c\\+\\+allocator.h$", "<string>"},
+      {"bits/c\\+\\+config.h$", "<iosfwd>"},
+      {"bits/c\\+\\+io.h$", "<ios>"},
+      {"bits/c\\+\\+locale.h$", "<locale>"},
       {"bits/cpu_defines.h$", "<iosfwd>"},
       {"bits/ctype_base.h$", "<locale>"},
       {"bits/cxxabi_tweaks.h$", "<cxxabi.h>"},
